==> neptune_widget_toolkit-5.2.0.15.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/composite/table/TableConstants.java <==
package com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table;


public interface TableConstants {
	static final int PAGESIZE_TEXT_SPACING = 3;
	static final int NAV_SPACING = 5;
	static final int BUTTON_SPACING = 5;
	static final int PANEL_SPACING = 3;
	static final int ROUNDED_PANEL_CORNER_HEIGHT = 9;

	static final String STYLE_TABLE_WIDGET = "nwt-Table";
	static final String STYLE_TABLE_PANEL = "nwt-TableListViewPanel";
	static final String STYLE_TABLE_RECORDCOUNT_PANEL = "nwt-TableListViewPanel-recordCount";
	static final String STYLE_TABLE_RECORDCOUNT_LABEL = "nwt-TableListViewPanel-recordCountLabel";
	static final String STYLE_TABLE_ACTION_PANEL = "nwt-TableListViewPanel-actions";
	static final String STYLE_TABLE_PAGING_PANEL = "nwt-TableListViewPanel-paging";
	static final String STYLE_TABLE_COLUMN_PANEL = "nwt-TableColumnPanel";
	static final String STYLE_HEADER_ROW = "table-header-row";
	static final String STYLE_HEADER_SORTABLE_COL_TEXT = "table-header-sortable-text";  
	static final String STYLE_HEADER_NONSORTABLE_COL_TEXT = "table-header-nonSortable-text";
	static final String STYLE_DATA_EVEN_ROW = "table-data-even-row";
	static final String STYLE_DATA_ODD_ROW = "table-data-odd-row";
	 static final String STYLE_DATA_CHECKBOX = "table-data-checkbox"; 
	static final String STYLE_DATA_TEXT = "table-data-text";
	static final String STYLE_DATA_ITALICS = "table-data-italics";
	static final String STYLE_DATA_LINK = "table-data-link";  
	static final String STYLE_GENERAL_TEXT = "table-general-text";
	static final String STYLE_GENERAL_TEXTBOX="table-general-textbox" ; 
	static final String STYLE_FORM_TEXTBOX="table-general-formtextbox" ; /* Added for ECMS*/
	static final String STYLE_FORM_LISTBOX="form-listbox";    /* Added for ECMS */
	static final String STYLE_FORM_CHECKBOX="form-checkbox" ; /* Added for ECMS */
	static final String STYLE_BUTTON = "table-button";
	static final String STYLE_NAV_BUTTON = "table-nav-button";
	//static final String STYLE_ADD_BUTTON = "ebBtn ebBtn_color_green margin-right10 margin-left10";
	//static final String STYLE_REMOVE_BUTTON ="ebBtn margin-right10";
	static final String STYLE_ADD_BUTTON = "addGreenButton";
	static final String STYLE_REMOVE_BUTTON ="deleteGrayButton";
	static final String STYLE_PAGE_SIZE_TABLE = "table-nav-pageSizeTable";
	static final String STYLE_PAGE_SIZE_CELL = "table-nav-pageSize-cell";
	static final String STYLE_CURRENT_PAGE_SIZE_CELL = "table-nav-currentPageSize-cell";
	static final String STYLE_FORM_LABEL = "table-form-label";
	static final String STYLE_FORM_VALUE = "table-form-value";
	static final String CHECK_BOX_COL_WIDTH = "2%";

	/** Style for all table data cells */
	static final String STYLE_DATACELL = "nwt-TableColumnPanel-dataCell";

	/** Style for table column cell which contains text data */
	static final String STYLE_DATACELL_TEXT = "nwt-TableColumnPanel-dataCell-text";

	/** Style for table column cell which contains numeric data */
	static final String STYLE_DATACELL_NUMERIC = "nwt-TableColumnPanel-dataCell-numeric";
	
	/** Style for table column cell which contains date / time data */
	static final String STYLE_DATACELL_DATE = "nwt-TableColumnPanel-dataCell-date";

	/** Style for table column cell which contains an icon / image */
	static final String STYLE_DATACELL_ICON = "nwt-TableColumnPanel-dataCell-icon";

	/** Style for table column cell which contains an icon / image and text*/
	static final String STYLE_DATACELL_ICON_TEXT = "nwt-TableColumnPanel-dataCell-icon-text";

	/** Style for table column cell which contains a check box */
	 static final String STYLE_DATACELL_CHECKBOX = "nwt-TableColumnPanel-dataCell-checkbox";  
	
	/** Style for table column cell which contains data of uncategorized type or a widget */
	static final String STYLE_DATACELL_GENERAL = "nwt-TableColumnPanel-dataCell-general";
	
	/** Style for list box in the create user page */
	static final String STYLE_ROLES_LISTBOX = "nwt-FormContainer-value-roles-ListBox";
	
}

==> neptune_widget_toolkit-5.2.0.157.jar: com/tandbergtv/neptune/widgettoolkit/client/widget/composite/table/TableConstants.java <==
package com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table;


public interface TableConstants {
	static final int PAGESIZE_TEXT_SPACING = 3;
	static final int NAV_SPACING = 5;
	static final int BUTTON_SPACING = 5;
	static final int PANEL_SPACING = 3;
	static final int ROUNDED_PANEL_CORNER_HEIGHT = 9;

	static final String STYLE_TABLE_WIDGET = "nwt-Table";
	static final String STYLE_TABLE_PANEL = "nwt-TableListViewPanel";
	static final String STYLE_TABLE_RECORDCOUNT_PANEL = "nwt-TableListViewPanel-recordCount";
	static final String STYLE_TABLE_RECORDCOUNT_LABEL = "nwt-TableListViewPanel-recordCountLabel";
	static final String STYLE_TABLE_ACTION_PANEL = "nwt-TableListViewPanel-actions";
	static final String STYLE_TABLE_PAGING_PANEL = "nwt-TableListViewPanel-paging";
	static final String STYLE_TABLE_COLUMN_PANEL = "nwt-TableColumnPanel";
	static final String STYLE_HEADER_ROW = "table-header-row";
	static final String STYLE_HEADER_SORTABLE_COL_TEXT = "table-header-sortable-text";  
	static final String STYLE_HEADER_NONSORTABLE_COL_TEXT = "table-header-nonSortable-text";
	static final String STYLE_DATA_EVEN_ROW = "table-data-even-row";
	static final String STYLE_DATA_ODD_ROW = "table-data-odd-row";
	 static final String STYLE_DATA_CHECKBOX = "table-data-checkbox"; 
	static final String STYLE_DATA_TEXT = "table-data-text";
	static final String STYLE_DATA_ITALICS = "table-data-italics";
	static final String STYLE_DATA_LINK = "table-data-link";  
	static final String STYLE_GENERAL_TEXT = "table-general-text";
	static final String STYLE_GENERAL_TEXTBOX="table-general-textbox" ; 
	static final String STYLE_FORM_TEXTBOX="table-general-formtextbox" ; /* Added for ECMS*/
	static final String STYLE_FORM_LISTBOX="form-listbox";    /* Added for ECMS */
	static final String STYLE_FORM_CHECKBOX="form-checkbox" ; /* Added for ECMS */
	static final String STYLE_BUTTON = "table-button";
	static final String STYLE_NAV_BUTTON = "table-nav-button";
	//static final String STYLE_ADD_BUTTON = "ebBtn ebBtn_color_green margin-right10 margin-left10";
	//static final String STYLE_REMOVE_BUTTON ="ebBtn margin-right10";
	static final String STYLE_ADD_BUTTON = "addGreenButton";
	static final String STYLE_REMOVE_BUTTON ="deleteGrayButton";
	static final String STYLE_PAGE_SIZE_TABLE = "table-nav-pageSizeTable";
	static final String STYLE_PAGE_SIZE_CELL = "table-nav-pageSize-cell";
	static final String STYLE_CURRENT_PAGE_SIZE_CELL = "table-nav-currentPageSize-cell";
	static final String STYLE_FORM_LABEL = "table-form-label";
	static final String STYLE_FORM_VALUE = "table-form-value";
	static final String CHECK_BOX_COL_WIDTH = "2%";

	/** Style for all table data cells */
	static final String STYLE_DATACELL = "nwt-TableColumnPanel-dataCell";

	/** Style for table column cell which contains text data */
	static final String STYLE_DATACELL_TEXT = "nwt-TableColumnPanel-dataCell-text";

	/** Style for table column cell which contains numeric data */
	static final String STYLE_DATACELL_NUMERIC = "nwt-TableColumnPanel-dataCell-numeric";
	
	/** Style for table column cell which contains date / time data */
	static final String STYLE_DATACELL_DATE = "nwt-TableColumnPanel-dataCell-date";

	/** Style for table column cell which contains an icon / image */
	static final String STYLE_DATACELL_ICON = "nwt-TableColumnPanel-dataCell-icon";

	/** Style for table column cell which contains an icon / image and text*/
	static final String STYLE_DATACELL_ICON_TEXT = "nwt-TableColumnPanel-dataCell-icon-text";

	/** Style for table column cell which contains a check box */
	 static final String STYLE_DATACELL_CHECKBOX = "nwt-TableColumnPanel-dataCell-checkbox";  
	
	/** Style for table column cell which contains data of uncategorized type or a widget */
	static final String STYLE_DATACELL_GENERAL = "nwt-TableColumnPanel-dataCell-general";
	
	/** Style for list box in the create user page */
	static final String STYLE_ROLES_LISTBOX = "nwt-FormContainer-value-roles-ListBox";
	
	/** Style for arrow Button in the create user page */
	static final String STYLE_ARROW_BUTTON = "arrowButton";
	
}
